# Core Developers
----------
- Farhan Farsi - Department of Computer Engineering, Amirkabir University of Technology ([GitHub](https://github.com/farhaaaaa))
- Parnian Fazel - School of Electrical and Computer Engineering, University of Tehran ([GitHub](https://github.com/parnianf))
- Nadia Hajipour - Ancient Culture and Languages, Institute for Humanities and Cultural Studies ([Academia](https://independent.academia.edu/nadiahajipour))
- Farzaneh Goshtasb - Ancient Culture and Languages, Institute for Humanities and Cultural Studies ([LinkedIn](https://www.linkedin.com/in/farzaneh-goshtasb-85892672/))
- Sepand Haghighi - Open Science Laboratory ([Github](https://github.com/sepandhaghighi)) **
- Sadra Sabouri - Open Science Laboratory ([Github](https://github.com/sadrasabouri)) **
- Ehsaneddin Asgari - Qatar Computing Research Institute - QCRI, Qatar ([GitHub](https://github.com/ehsanasgari))
- Hossein Sameti - Computer Engineering Department, Sharif University of Technology ([Webpage](https://sharif.edu/~sameti/))

** **Maintainer**

# Other Contributors
----------


